﻿using System.Threading.Tasks;
using Amazon.DynamoDBv2.DataModel;
using AutoMapper;
using DynamoDbApiObjectApproach.Models;
using Microsoft.AspNetCore.Mvc;

namespace DynamoDbApiObjectApproach.Controllers
{
    [ApiController]
    [Route("[controller]")]
    public class PersonController : ControllerBase
    {
        private readonly IMapper _mapper;
        private readonly IDynamoDBContext _dynamoDBContext;

        public PersonController(IDynamoDBContext dynamoDBContext, IMapper mapper)
        {
            _dynamoDBContext = dynamoDBContext;
            _mapper = mapper;
        }

        [HttpGet("{personId}")]
        public async Task<IActionResult> Get(int personId)
        {
            var personDynamoDb = await _dynamoDBContext.LoadAsync<PersonDynamoDb>(personId);
            var person = _mapper.Map<Person>(personDynamoDb);

            return Ok(person);
        }

        [HttpPost]
        public async Task<IActionResult> Post(Person person)
        {
            var personDynamoDb = _mapper.Map<PersonDynamoDb>(person);
            await _dynamoDBContext.SaveAsync(personDynamoDb);

            return Created("", person.PersonId);
        }
    }
}
